@@ -5,7 +5,7 @@ package Tk::Clock;
 use strict;
 use warnings;
 
-our $VERSION = "0.44";
+our $VERSION = "0.45";
 
 use Carp;
 
@@ -50,6 +50,17 @@ my %def_config = (
     infoFormat	=> "HH:MM:SS",
     infoFont	=> "fixed 6",
 
+    useText	=> 0,
+
+    textColor	=> "#c4c4c4",
+    textFormat	=> " ",
+    textFont	=> "fixed 6",
+
+    time2Font	=> "fixed 6",
+    time2Color	=> "Gray30",
+    time2Format	=> "",
+    time2TZ	=> "",
+
     useDigital	=> 1,
 
     digiAlign	=> "center",
@@ -71,6 +82,9 @@ my %def_config = (
     fmti	=> sub {
 	sprintf "%02d:%02d:%02d", @_[2,1,0];
 	},
+    fmt2	=> sub {
+	sprintf "%02d:%02d:%02d", @_[2,1,0];
+	},
 
     _anaSize	=> $ana_base,	# Default size (height & width)
     _digSize	=> 26,		# Height
@@ -117,6 +131,7 @@ sub _booleans {
 	useAnalog
 	useDigital
 	useInfo
+	useText
 	useSecHand
 	);
     } # _booleans
@@ -327,6 +342,27 @@ sub _where {
     ($h - $x / 4, $h + $y / 4, $h + $x, $h - $y);
     } # _where
 
+sub _timeText {
+    my ($data, $tag) = @_;
+    my $tf = $data->{"${tag}Format"};
+    local $ENV{TZ} = $data->{"${tag}TZ"} || $data->{timeZone} || $ENV{TZ};
+    my $text = ref $tf eq "CODE"   ? $tf->(localtime)
+	     : ref $tf eq "SCALAR" ? $$tf : $tf;
+    return $text;
+    } # _timeText
+
+sub _createTimeText {
+    my ($clock, $data, $tag, $h, $f) = @_;
+	my $text = _timeText ($data, $tag);
+	$clock->createText ($h, int ($f * $h),
+	    -anchor => "n",
+	    -width  => int (1.2 * $h),
+	    -font   => $data->{"${tag}Font"},
+	    -fill   => $data->{"${tag}Color"},
+	    -text   => $text,
+	    -tags   => $tag);
+    } # _createTimeText
+
 sub _createAnalog {
     my $clock = shift;
 
@@ -350,6 +386,20 @@ sub _createAnalog {
 	    -text   => $data->{infoFormat},
 	    -tags   => "info");
 	}
+    if ($data->{useText}) {
+	_createTimeText ($clock, $data, "text",  $h, 1.5);
+	}
+    if ($data->{time2TZ}) {
+	$data->{time2TZ} ||= "UTC";
+	$data->{time2Format} or $clock->config (time2Format => "HH:MM:SS");
+	unless (ref $data->{time2Format}) {
+	    ref $data->{fmt2} and $data->{time2Format} = $data->{fmt2};
+	    }
+	_createTimeText ($clock, $data, "time2", $h, 0.7);
+	}
+    else {
+	$data->{time2Format} = "";
+	}
 
     my $f = $data->{tickFreq} * 2;
     foreach my $dtick (0 .. 119) {
@@ -420,7 +470,7 @@ sub _createAnalog {
 sub _destroyAnalog {
     my $clock = shift;
 
-    $clock->delete ($_) for qw( back info tick hour min sec );
+    $clock->delete ($_) for qw( back text info time2 tick hour min sec );
     } # _destroyAnalog
 
 sub Populate {
@@ -465,6 +515,8 @@ my %attr_weight = (
     digiAlign	=> 99985,
     useAnalog	=> 99990,
     useInfo	=> 99991,
+    useText	=> 99991,
+    time2TZ	=> 99991,
     tickFreq	=> 99992,
     anaScale	=> 99995,
     useLocale	=>     1,
@@ -507,7 +559,7 @@ sub config {
 	    keys %$conf) {
 	(my $attr = $conf_spec) =~ s/^-//;
 	$attr =~ m/^_/ and next; # Internal use only!
-	defined $def_config{$attr} && defined $data->{$attr} or next;
+	exists $def_config{$attr} && exists $data->{$attr} or next;
 	my $old = $data->{$attr};
 	$data->{$attr} = $conf->{$conf_spec};
 	if    ($attr eq "tickColor") {
@@ -532,16 +584,29 @@ sub config {
 	elsif ($attr eq "timeFont") {
 	    $clock->itemconfigure ("time", -font => $data->{timeFont});
 	    }
+	elsif ($attr eq "time2Color") {
+	    $clock->itemconfigure ("time2",-fill => $data->{time2Color});
+	    }
+	elsif ($attr eq "time2Font") {
+	    $clock->itemconfigure ("time2",-font => $data->{time2Font});
+	    }
 	elsif ($attr eq "infoColor") {
 	    $clock->itemconfigure ("info", -fill => $data->{infoColor});
 	    }
 	elsif ($attr eq "infoFont") {
 	    $clock->itemconfigure ("info", -font => $data->{infoFont});
 	    }
+	elsif ($attr eq "textColor") {
+	    $clock->itemconfigure ("text", -fill => $data->{textColor});
+	    }
+	elsif ($attr eq "textFont") {
+	    $clock->itemconfigure ("text", -font => $data->{textFont});
+	    }
 	elsif ($attr eq "useLocale") {
 	    $locale{$data->{useLocale}} or _newLocale ($data->{useLocale});
 	    }
-	elsif ($attr eq "dateFormat" || $attr eq "timeFormat" || $attr eq "infoFormat") {
+	elsif ($attr eq "dateFormat" || $attr eq "timeFormat" || $attr eq "time2Format" ||
+	       $attr eq "infoFormat" || $attr eq "textFormat") {
 	    my %fmt = (
 		"S"	=> '%d',	# 45
 		"SS"	=> '%02d',	# 45
@@ -600,7 +665,7 @@ sub config {
 		    }
 		}
 	    $data->{Clock_h} = -1;	# force update;
-	    $data->{"fmt".substr $attr, 0, 1} = eval join "\n" =>
+	    my $cb = eval join "\n" =>
 		 q[ sub							],
 		 q[ {							],
 		 q[     my ($S,  $M,  $H, $d, $m, $y, $wd, $yd, $dst,	],
@@ -612,6 +677,8 @@ sub config {
 		 q[     $h ||= 12;					],
 		qq[     sprintf qq!$fmt!$args;				],
 		 q[     }						];
+	    my $fmt_tag = $attr =~ m/^time2/ ? "2" : substr $attr, 0, 1;
+	    $data->{"fmt$fmt_tag"} = $cb;
 	    }
 	elsif ($attr eq "timerValue") {
 	    $data->{timerStart} = $data->{timerValue} ? time : undef;
@@ -686,6 +753,26 @@ sub config {
 		}
 	    $clock->after (5, ["_run" => $clock]);
 	    }
+	elsif ($attr eq "useText") {
+	    if ($old ^ $data->{useText} && $data->{useAnalog}) {
+		$clock->_destroyAnalog;
+		$clock->_destroyDigital;
+		$clock->_createAnalog;
+		$data->{useDigital} and $clock->_createDigital;
+		}
+	    $clock->after (5, ["_run" => $clock]);
+	    }
+	elsif ($attr eq "time2TZ") {
+	    defined $data->{time2TZ} or $data->{time2TZ} = "";
+	    if ($old ^ $data->{time2TZ} && $data->{useAnalog}) {
+		$data->{time2TZ} && !$data->{time2Format} and $clock->config (time2Format => "HH:MM:SS");
+		$clock->_destroyAnalog;
+		$clock->_destroyDigital;
+		$clock->_createAnalog;
+		$data->{useDigital} and $clock->_createDigital;
+		}
+	    $clock->after (5, ["_run" => $clock]);
+	    }
 	elsif ($attr eq "useDigital") {
 	    if    ($old == 1 && !$data->{useDigital}) {
 		$clock->_destroyDigital;
@@ -780,14 +867,14 @@ sub _run {
 	    $clock->coords ("sec",
 		$clock->_where ($data->{Clock_s}, 34, $data->{_anaSize}));
 	$data->{fmti} ||= sub { sprintf "%02d:%02d:%02d", @_[2,1,0]; };
-	$data->{useInfo} and
-	    $clock->itemconfigure ("info", -text => $data->{fmti}->(@t));
+	$data->{useInfo} ? $clock->itemconfigure ("info",  -text => $data->{fmti}->(@t))        : $clock->delete ("info");
+	$data->{useText} ? $clock->itemconfigure ("text",  -text => _timeText ($data, "text"))  : $clock->delete ("text");
+	$data->{time2TZ} ? $clock->itemconfigure ("time2", -text => _timeText ($data, "time2")) : $clock->delete ("time2");
 	}
     $data->{fmtt} ||= sub { sprintf "%02d:%02d:%02d", @_[2,1,0]; };
-    $data->{useDigital} and
-	$clock->itemconfigure ("time", -text => $data->{fmtt}->(@t));
+    $data->{useDigital}  and $clock->itemconfigure ("time",  -text => $data->{fmtt}->(@t));
 
-    $data->{autoScale} and $clock->_resize_auto;
+    $data->{autoScale}   and $clock->_resize_auto;
     } # _run
 
 1;
@@ -800,7 +887,7 @@ Tk::Clock - Clock widget with analog and digital display
 
 =head1 SYNOPSIS
 
-  use Tk
+  use Tk;
   use Tk::Clock;
 
   $clock = $parent->Clock (?-option => <value> ...?);
@@ -829,6 +916,14 @@ Tk::Clock - Clock widget with analog and digital display
       infoColor   => "#cfb53b",
       infoFormat  => "HH:MM:SS",
       infoFont    => "fixed 6",
+      useText     => 0,
+      textColor   => "#c4c4c4",
+      textFormat  => "HH:MM:SS",
+      textFont    => "fixed 6",
+      time2Font   => "fixed 6",
+      time2Color  => "Red4",
+      time2Format => "HH:MM:SS",
+      time2TZ     => "Europe/Amsterdam",
 
       useDigital  => 1,
       digiAlign   => "center",
@@ -865,18 +960,20 @@ default value is in between parenthesis.
 
 =item useInfo (0)
 
+=item useText (0)
+
 =item useDigital (1)
 
 Enable the analog clock (C<useAnalog>) and/or the digital clock (C<useDigital>)
 in the widget. The analog clock will always be displayed above the digital part
 
-  +----------+
-  |    ..    |  \
-  |  . \_ .  |   |_ Analog clock
-  |  .    .  |   |
-  |    ..    |  /
-  | 23:59:59 |  --- Digital time
-  | 31-12-09 |  --- Digital date
+  +----------+                                   ......
+  |    ..    |  \                              . \ |    .
+  |  . \_ .  |   |_ Analog clock              .   Tim2   .
+  |  .    .  |   |                            .    *     .
+  |    ..    |  /                             .   Info   .
+  | 23:59:59 |  --- Digital time               .  Text  .
+  | 31-12-09 |  --- Digital date                 ......
   +----------+
 
 The analog clock displays ticks, hour hand, minutes hand and second hand.
@@ -886,6 +983,12 @@ these are time and date.
 The C<useInfo> enables a text field between the backdrop of the analog
 clock and its items. You can use this field to display personal data.
 
+The C<useText> is like second line of C<useInfo>, but with support for
+callbacks or variable binding.
+
+  $clock->configure (useText => 1, textFormat => \$foo);
+  $clock->configure (useText => 1, textFormat => sub { int rand 42 });
+
 =item autoScale (0)
 
 When set to a true value, the widget will try to re-scale itself to
@@ -1043,6 +1146,35 @@ C</> or C<space>.
 The text shown in the formats C<ddd>, C<dddd>, C<mmm>, and C<mmmm> might be
 influenced by the setting of C<useLocale>. The fallback is locale "C".
 
+=item time2Font ("fixed 6")
+
+Controls the font to be used for the alternate time in the analog clock. Will
+accept all fonts that are supported in your version of perl/Tk. This includes
+both True Type and X11 notation.
+
+  $clock->config (time2Font => "{Liberation Mono} 11");
+
+=item time2Color ("Gray30")
+
+Controls the color of the alternate time line of the analog clock.
+
+  $clock->config (time2Color => "#00ff00");
+
+=item time2Format ("HH:MM:SS")
+
+Defines the format of the alternate time line of the analog clock. By
+default it will display the time in a 24-hour notation.
+
+The supported format is the same as for C<timeFormat>.
+
+=item time2TZ ("Europe/Amsterdam")
+
+Define the time zone for the alternate time in the analog clock. When
+empty, it disables the display of an alternate time.
+
+ $clock->config (time2TZ => "");
+ $clock->config (time2TZ => "UTC");
+
 =item dateFont ("fixed 6")
 
 Controls the font to be used for the bottom line in the digital clock. Will
@@ -1172,7 +1304,7 @@ Thanks to all who have given me feedback and weird ideas.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 1999-2023 H.Merijn Brand
+Copyright (C) 1999-2026 H.Merijn Brand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
